import os
import logging
from flask import Flask


def create_app(test_config=None):
    app = Flask(__name__, instance_relative_config=True)

    try:
        os.makedirs(app.instance_path)
    except OSError:
        pass
    
    app.config.from_object('checklist.default_list')  # Read default list
    app.config.from_pyfile('list.py', silent=True)

    gunicorn_logger = logging.getLogger('gunicorn.error')  # Gunicorn logging integration
    app.logger.handlers = gunicorn_logger.handlers
    app.logger.setLevel(gunicorn_logger.level)

    from . import checklist  # Set up blueprints
    app.register_blueprint(checklist.clbp)

    return app


if __name__ == '__main__':
    create_app()
